@@ -23,7 +23,7 @@
 
 #include <QtQml>
 
-#define GC_DEFAULT_FONT QLatin1String("Andika-R.otf")
+#define GC_DEFAULT_FONT QLatin1String("Andika-R.ttf")
 #define GC_DEFAULT_FONT_CAPITALIZATION 0 // Font.MixedCase
 #define GC_DEFAULT_FONT_LETTER_SPACING 0
 
@@ -67,6 +67,7 @@ static const char *DEFAULT_CURSOR = "defaultCursor";
 static const char *NO_CURSOR = "noCursor";
 static const char *KIOSK_KEY = "kiosk";
 static const char *SECTION_VISIBLE = "sectionVisible";
+static const char *EXIT_CONFIRMATION = "exitConfirmation";
 static const char *WORDSET = "wordset";
 static const char *USE_WORDSET = "useWordset";
 
@@ -98,8 +99,8 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
                               .toBool();
     m_locale = m_config.value(LOCALE_KEY, GC_DEFAULT_LOCALE).toString();
     m_font = m_config.value(FONT_KEY, GC_DEFAULT_FONT).toString();
-    if (m_font == QLatin1String("Andika-R.ttf"))
-        m_font = "Andika-R.otf";
+    if (m_font == QLatin1String("Andika-R.otf"))
+        m_font = "Andika-R.ttf";
     m_fontCapitalization = m_config.value(FONT_CAPITALIZATION, GC_DEFAULT_FONT_CAPITALIZATION).toUInt();
     m_fontLetterSpacing = m_config.value(FONT_LETTER_SPACING, GC_DEFAULT_FONT_LETTER_SPACING).toReal();
     m_isEmbeddedFont = m_config.value(IS_CURRENT_FONT_EMBEDDED, true).toBool();
@@ -114,6 +115,7 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
 #endif
 
     m_sectionVisible = m_config.value(SECTION_VISIBLE, true).toBool();
+    m_exitConfirmation = m_config.value(EXIT_CONFIRMATION, ApplicationInfo::getInstance()->isMobile() ? true : false).toBool();
     m_wordset = m_config.value(WORDSET, "").toString();
 
     // Automatically override the previous rcc with the new one
@@ -171,6 +173,7 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
     connect(this, &ApplicationSettings::filterLevelMinChanged, this, &ApplicationSettings::notifyFilterLevelMinChanged);
     connect(this, &ApplicationSettings::filterLevelMaxChanged, this, &ApplicationSettings::notifyFilterLevelMaxChanged);
     connect(this, &ApplicationSettings::sectionVisibleChanged, this, &ApplicationSettings::notifySectionVisibleChanged);
+    connect(this, &ApplicationSettings::exitConfirmationChanged, this, &ApplicationSettings::notifyExitConfirmationChanged);
     connect(this, &ApplicationSettings::wordsetChanged, this, &ApplicationSettings::notifyWordsetChanged);
     connect(this, &ApplicationSettings::useWordsetChanged, this, &ApplicationSettings::notifyUseWordsetChanged);
     connect(this, &ApplicationSettings::kioskModeChanged, this, &ApplicationSettings::notifyKioskModeChanged);
@@ -207,6 +210,7 @@ ApplicationSettings::~ApplicationSettings()
     m_config.setValue(FILTER_LEVEL_MAX, m_filterLevelMax);
     m_config.setValue(KIOSK_KEY, m_isKioskMode);
     m_config.setValue(SECTION_VISIBLE, m_sectionVisible);
+    m_config.setValue(EXIT_CONFIRMATION, m_exitConfirmation);
     m_config.setValue(WORDSET, m_wordset);
     m_config.setValue(USE_WORDSET, m_useWordset);
     m_config.setValue(DEFAULT_CURSOR, m_defaultCursor);
@@ -366,6 +370,11 @@ void ApplicationSettings::notifySectionVisibleChanged()
     qDebug() << "notifySectionVisible: " << m_sectionVisible;
 }
 
+void ApplicationSettings::notifyExitConfirmationChanged()
+{
+    updateValueInConfig(GENERAL_GROUP_KEY, EXIT_CONFIRMATION, m_exitConfirmation);
+}
+
 void ApplicationSettings::notifyWordsetChanged()
 {
     if (!m_wordset.isEmpty() && DownloadManager::getInstance()->haveLocalResource(m_wordset) && !DownloadManager::getInstance()->isDataRegistered("words-webp")) {
